Return the design rows in a random order. I'd shuffle the order before generating materials or presenting them to raters. Supply a seed if you want to reproduce the shuffle.
Examples
d <- design_conditions(frame = c("a", "b", "c"))
#> ℹ Design: 3 conditions from 1 factor
randomize_design(d, seed = 42)
#> # A tibble: 3 × 2
#> condition_id frame
#> <int> <chr>
#> 1 1 a
#> 2 3 c
#> 3 2 b